@@ -1,8 +1,8 @@
 #! /usr/bin/python
 # -*- coding: utf-8 -*-
 
-import logging
-logger = logging.getLogger(__name__)
+from loguru import logger
+
 
 import os.path
 import sys
